# Open Education Austria Documentation

## Table of Contents

-   [Installation](#installation)

    -   [Client](#client)

    -   [Server](#server)

-   [REST API Documentation](#rest)

    -   [POST /search/](#search)

        -   [Request body example](#search-request)

        -   [Properties and types](#search-properties)

    -   [POST /search/favorites](#favorites)

        -   [Request body example](#favorites-request)

        -   [Properties and types](#favorites-properties)

    -   [GET /search/:id](#id)

        -   [Example](#id-example)

    -   [GET /author/:name](#author)

        -   [Example](#author-example)

-   [ENV Files](#env)

    -   [Server](#env-server)

# <a id='installation'>Installation</a>

<br>

## <a id='client'>Client</a>

```
$ cd client/

$ npm i

$ npm start
```
Password-protection:

index.vue is password protected...to remove this, replace it with index-no-password.vue.

<br>

## <a id='server'>Server</a>

```
$ cd server/

$ npm i

$ npm run build

$ npm start
```

<br>

# <a id='rest'>REST API Documentation</a>

## <a id='search'>POST /search/</a>

_Retrieves all of the documents based on the query_

<a id='search-request'>Request body</a>

```
{
  "query": "der",
  "page": 0,
  "size": 10,
  "disciplines": [
    {
      "id": "102",
      "nameEn": "Computer Sciences",
      "nameDe": "Informatik"
    },
    {
      "id": "101005",
      "nameEn": "Computer algebra",
      "nameDe": "Computeralgebra"
    }
  ],
  "mediaTypes": [
    "Video",
    "Document",
    "Picture",
    "Miscellaneous",
    "Audio"
  ],
  "sources": [
    "phaidra.univie.ac.at",
    "openlib.tugraz.at"
  ],
  "licences": [
    "CC",
    "CC BY 4.0 International"
  ],
  "dateRange": "now-1y/d",
  "sort": {
    "type": "date",
    "order": "desc"
  },
  "startDate": "",
  "endDate": ""
}
```

<a id='search-properties'>Properties</a>

```
Property        Type                 Required/Optional
_______________________________________________________
query        |  String             | Required         |
page         |  Int                | Required         |
size         |  Int                | Required         |
disciplines  |  Array[Object]      | Optional         |
mediaTypes   |  Array[String]      | Optional         |
sources      |  Array[String]      | Optional         |
licences     |  Array[String]      | Optional         |
dateRange    |  String             | Optional         |
sort         |  Object{}           | Optional         |
startDate    |  String(YYYY-MM-DD) | Optional         |
endDate      |  String(YYYY-MM-DD) | Optional         |
```

<br>

## <a id='favorites'>POST /search/favorites</a>

_Retrieves all of the documents based on an array of IDs_

<a id='favorites-request'>Request body</a>

```
{
  "ids": [
    "o:1127269",
    "5e43be9ad90ed"
  ]
}
```

<a id='favorites-properties'>Properties</a>

```
Property        Type                 Required/Optional
_______________________________________________________
ids         |  Array[String]       | Required         |
```

<br>

## <a id='id'>GET /search/:id</a>

_Retrieves a document for the given ID_

<a id='id-example'>Example</a>

```
curl --location --request GET 'http://localhost:3033/search/5e43be9ad90ed'
```

<br>

## <a id='author'>GET /author/:name</a>

_Retrieves all of the documents based on the authors name_

<a id='author-example'>Example</a>

```
curl --location --request GET 'http://localhost:3033/author/Alicja_Malgorzata_Michalowska-Forsyth'
```

<br>

# <a id='env'>ENV Files</a>

<br>

## <a id='env-server'>Server</a>

```
URL=https://portal.openeducation.at/q/v1/ #URL for elasticsearch requests
ENV=DEV
PORT=3033 #Port on which server is running
```

