export default {
  // see https://nuxtjs.org/docs/2.x/configuration-glossary/configuration-dev
  dev: process.env.NODE_ENV !== 'production',

  publicRuntimeConfig: {
    analyticsServerBaseUrl: process.env.ANALYTICS_SERVER_BASE_URL || '',
    analyticsSiteId: process.env.ANALYTICS_SITE_ID || '1'
  },

  // Global page headers (https://go.nuxtjs.dev/config-head)
  head: {
    title: 'Open Education Austria',
    meta: [{ charset: 'utf-8' }, { name: 'viewport', content: 'width=device-width, initial-scale=1' }, { hid: 'description', name: 'description', content: '' }],
    link: [
      { rel: 'icon', type: 'image/x-icon', href: '/favicon.ico' },
      {
        rel: 'stylesheet',
        href: 'https://fonts.googleapis.com/css2?family=Roboto:ital,wght@0,100;0,300;0,400;0,700;0,900;1,100;1,300;1,400;1,500;1,700;1,900&display=swap',
      },
    ],
  },

  // Global CSS (https://go.nuxtjs.dev/config-css)
  css: ['@/assets/css/main.css'],

  // Plugins to run before rendering page (https://go.nuxtjs.dev/config-plugins)
  // Matomo plugin (https://matomo.org/integrate/#programming-language-platforms-and-frameworks)
  plugins: [
    { src: '~/plugins/vue-matomo.js', ssr: false }
  ],

  // Auto import components (https://go.nuxtjs.dev/config-components)
  components: true,

  // Modules for dev and build (recommended) (https://go.nuxtjs.dev/config-modules)
  buildModules: [
    // https://go.nuxtjs.dev/typescript
    '@nuxt/typescript-build',
    // https://go.nuxtjs.dev/tailwindcss
    '@nuxtjs/tailwindcss',
    [
      'nuxt-fontawesome',
      {
        component: 'icon',
        imports: [
          {
            set: '@fortawesome/free-solid-svg-icons',
            icons: ['fas'],
          },
          {
            set: '@fortawesome/free-regular-svg-icons',
            icons: ['faStar'],
          },
        ],
      },
    ],
  ],

  // Modules (https://go.nuxtjs.dev/config-modules)
  modules: [
    // https://go.nuxtjs.dev/axios
    '@nuxtjs/axios',
    'nuxt-i18n',
    'nuxt-password-protect'
  ],
  router: {
     middleware: ['password-protect'] // Enable to protect the entire website
  },

  // Axios module configuration (https://go.nuxtjs.dev/config-axios)
  axios: {
      baseURL: process.env.FRONTEND_SERVER_BASE_URL || "https://portal.openeducation.at",
  },

  // Build Configuration (https://go.nuxtjs.dev/config-build)
  build: {
  },

  passwordProtect: {
    enabled: false, //if you want to use protection set it to: true
    formPath: '/index-with-password',
    password: 'oeaa#2022',
    tokenSeed: 3343490,
    queryString: '_pw',
    cookieName: '_password',
    ignoredPaths: ['/contact', '/imprint']
  },
  i18n: {
    locales: ['en', 'de'],
    defaultLocale: 'de',
    vueI18n: {
      fallbackLocale: 'en',
      messages: {
        en: {
          favorites: 'Favorites',
          search: 'Search',
          discipline: 'Discipline',
          learningRT: 'Resource',
          language: 'Language',
          licence: 'Licence',
          aboutLicence: 'About Creative Commons Licences',
          ccUrl: 'https://creativecommons.org/licenses/?lang=en',
          moreInfo: 'more Information',
          date: 'Date',
          source: 'Source',
          imprint: 'Imprint',
          imprintContent: [
            { header: 'Maintainer of the OERhub',
              description: 'XXXX XXXX<br>Street X<br>XXXX Xxxx'
            },            
            { header: 'Copyright',
              description: 'The source code of the OERhub is published as open source with Apache 2.0 license. The creation, use and non-commercial distribution of copies in electronic or printed form are permitted if the source is acknowledged.<br>All OER objects found and displayed from the linked repositories contain information on the respective authors and license details, which must be taken into account.'
            },
            { header: 'Liability',
              description: 'All texts on the OERhub have been carefully checked. Nevertheless, no guarantee can be given for the correctness, completeness and topicality of the information.<br>Liability for the OER objects found in the linked systems lies with the respective source..'
            }
          ],          
          favsDesc: 'Favourites are stored as cookies and are therefore only saved on this device. If you call up the OERhub on another device, you will not be able to access your favourites.',
          favsNotExist: 'No Favourites on this device!',
          mediaType: 'Media',
          sponsor: 'Funding',
          partner: 'Projectpartner of Open Education Austria Advanced:',
          searchTooltip: 'How does the search work?',
          heading: 'Search and find Open Educational Resources (OER)',
          description1:
            'OERhub - Search engine for open educational resources',
          description2:
            '',
          description3:
            '',
          contact: 'Contact',
          contactContent: [
            { header: 'Technical Support',
              description: '',
              person: [ { contact: '<b>Max Mustermann/b><br>Details' } ]
            }
          ],          
          disclaimer: 'Disclaimer',          
          disclaimer1: 'Now and Future',
          disclaimer2: 'It is important to us that you are supported in finding the OER you are looking for. Therefore, in the course of developing the OERhub, we pay special attention to the user-friendly display of the metadata provided to us. We work together with the repositories connected to the OERhub to provide you with the best possible search results.<br><br>Currently connected to the OERhub are the OER repositories of the University of Vienna, University of Graz, University of Innsbruck, Graz University of Technology and the Austrian MOOC platform iMooX and Archivesystem of the Project DigiFit4All.<br><br>In the course of the project, all developments around the OERhub will also be made freely available as open source products.',
          dataProtection: 'Data Protection',
          project: 'Project',
          home: 'Home',
          faq: 'FAQ',
          faqContent: [
            { header: 'The concept of the OERhub',
              description: [ { subheader: '', text: 'Teaching staff can store and release their OER in one of the connected institutional archive systems according to the owner principle. The OERhub makes these locally stored OER available for broad use beyond their own institution. The centralized OERhub for OER from the higher education sector thus contributes to the national and international visibility of teaching.<br>Conceptually, a decentralized approach is pursued; the universities continue to bear responsibility for their local infrastructures (production processes, archiving). The OERhub follows the FAIR Data principles and can be easily expanded to include other universities thanks to its modular architecture and open interfaces. The OERhub is also GDPR-compliant in its handling of data.' } ]
            },
            { header: 'Principles of the OERhub',
              description: [ { subheader: '', text: 'In accordance with the European Open Science Cloud (EOSC, 2020) and the international standards for handling research data, the OERhub is based on the FAIR Data principles. The technological architecture of the OERhub can easily be expanded and thus facilitates the connection of local architectures.' } ]
            },
            { header: 'Requirements and specifications for connecting a repository to the OERhub',
              description: [ { subheader: '', text: '<ul class="list-inside list-decimal"><li>The first requirement is that the metadata must be provided to OERHub in the LOM schema. The fields ‘Title’, ‘Author’, ‘Date’ and licence information are mandatory. Information on the discipline - described via the ÖFOS (Statistik Austria, 2017) - and the media type (MIME type) is required so that the OER found can be filtered via the facets. A meaningful description of the didactic embedding of the learning object also increases the quality of the search.</li><li>The second requirement is the persistent link as a reference to a landing page. All relevant information and the download of the teaching/learning object can be found on this page.</li><li>The third requirement is that the object itself must be offered with an open Creative Commons licence.</li></ul>You can download the TwoPager as a summary here: <a href="https://phaidra.univie.ac.at/detail/o:2110159" _target="_extWindow">TwoPager</a>' } ]
            },
            { header: 'Interfaces for connecting to the OERhub',
              description: [ { subheader: '', text: 'Due to the open architecture of the OERhub, decentralized university repositories or other local systems can be connected to the OERhub in various ways. The options range from the OAI-PMH interface, the OERhub application programming interfaces (API) and other connectors.' } ]
            }                                      
          ],
          resultsFor: 'Results for',
          itemFrom: 'Viewing',
          itemTo: 'to',          
          toPress: 'To press',
          sortBy: 'Sorted by: ',
          author: 'Authors',
          uploadDate: 'Uploaded on',
          updateDate: 'Last updated on',
          loading: 'One moment please. Your results are loading...',
          noSearchResults: 'Your search returned no results.',
          back: 'Back',
          continue: 'Continue',
          btnJumpTop: 'Top',
          btnJumpBottom: 'Bottom',
          seekDiscipline: 'Seek discipline',
          seekLearningRT: 'Seek resource',
          seekLanguage: 'Seek language',
          reset: 'Reset',
          save: 'Apply',
          today: 'Today',
          lastWeek: 'Last Week',
          lastMonth: 'Last Month',
          lastYear: 'Last Year',
          metaData: 'Metadata',
          metaDataDescription: 'The following additional information is available for this entry:',
          report: 'Report entry',
          reportExplanation: 'Please tell us the reason why you would like to report this entry.',
          copy: 'Copy link source',
          entries: 'Entries',
          titleAsc: 'Title A - Z',
          titleDesc: 'Title Z - A',
          uploadDateAsc: 'Upload date: ascending',
          uploadDateDesc: 'Upload date: descending',
          scoreAsc: 'Score: ascending',
          scoreDesc: 'Score: descending',          
          remove: 'Remove',
          customDate: 'Date period',
          from: 'From',
          to: 'To',
          descriptionLicence: 'CC = Creative Commons, BY = Attribution, NC = Non-Commercial, ND = No Derivatives, SA = Share Alike ---- more Details on the Homepage ',
          favoriteTooltip: 'Mark as favorite',
          cancel: 'Cancel',
          send: 'Send',
          resetFilters: 'Clear Filters',
          copied: 'Link source copied',
          welcomeHead1: 'Welcome!',
          isAuthorisedHead1: 'Logged in',
          isAuthorisedDecision: 'Here you ara able to log out or continue with the Search ... ',
          lnkLogout: 'Log out',
          lnkSearch: 'Search',
          askPaswordHead1: 'Log in',
          askPasswordTxt: 'Please enter your Password ...',
          hintPassword: 'Password ...',
          btnPassword: 'Log in',
          btnReset: 'Remove Search Term',
          btnSearch: 'Search',
          descriptionSearch: 'The words in the textfield are used for the search about author, title or description. We use an intelligent search algorithm to get best results. With the use of Filter-boxes you are able to specify more details. ',
          jsonExport: 'Export as JSON',
          accessibility: 'Accessibility',
          accessibilityContent: [
            { header: 'Declaration of Accessibility',
              description: 'During the implementation of the OERhub community edition v. 1.0., the project team was committed to making the OERhub accessible in accordance with the Web Accessibility Act (WZG) as amended, to implement Directive (EU) 2016/2102 of the European Parliament and the Council of 26 October 2016 on the accessibility of websites and mobile applications of public sector bodies (Official Journal L 327, 2.12.2016, p. 1).<br><br>This accessibility declaration applies to the websites www.example.at.'
            },
            { header: 'Compliance Status',
              description: 'The websites are partially compliant with the Web Content Accessibility Guidelines (WCAG) due to the incompatibilities and exceptions outlined below.<br><br>The underlying criteria are based on WCAG 2.1 conformance level AA and the European Standard EN 301 549 V3.1.2 (PDF).<br><br>Section 9.6 of the WCAG conformance requirements in EN 301 549 is not met, as the WCAG 2.1 Level AA standards are only partially fulfilled.',
            },
            { header: 'Non-Accessible Content',
              description: '<ul class="list-inside list-disc"><li>Mobile content displays errors when zoomed beyond 150%.</li><li>Link descriptions are not consistently WCAG-compliant.</li><li>Labels for user interface elements are partially not WCAG-compliant.</li><li>Foreign language text passages are sometimes not marked.</li><li>Certain overlapping areas remain open when navigating with the keyboard and cannot be closed via keyboard commands.</li><li>The search area is not semantically marked.</li></ul>',
            },
            { header: 'Content Outside the Scope of Applicable Legal Requirements',
              description: 'Content from third parties that the maintainer of the website www.example.at does not have control over is exempt from Directive (EU) 2016/2102. No claims can be made regarding compliance with accessibility requirements for such third-party content.',
            },
            { header: 'Creation of This Accessibility Declaration',
              description: 'This declaration was created on April 11, 2023. Last updated: December 1, 2024.<br><br>The compliance of the websites with the Web Accessibility Act to implement the requirements of Directive (EU) 2016/2102 was assessed through an external accessibility audit based on WCAG 2.1 at compliance level AA in October 2024.',
            },
            { header: 'Feedback and Contact Information',
              description: 'If you encounter any barriers that hinder your use of this website - issues not described in this declaration or more significant deficiencies concerning accessibility requirements - please inform us via [CHANNEL]. We will review your inquiry and contact you as soon as possible. Please send all communications and suggestions to <a href="mailto:office@example.at?subject=accessibility - complaints">office@example.at</a>. Describe the issue and specify the area in question.',
            },
            { header: 'Contact',
              description: '[CONTACT INFORMATION]',
            },
            { header: 'Enforcement Procedure',
              description: 'If the response from the above-mentioned contact does not satisfy you, you can submit a complaint to [NAME OF AUTHORITY]. Complaints can be submitted electronically via the contact form: <a class="green-one" href="https://LINK" target="_extFFG">https://LINK</a><br><br>The [NAME OF AUTHORITY] examines complaints to determine whether they relate to violations of the Web Accessibility Act, particularly shortcomings in meeting accessibility requirements by the federal government or associated entities.<br><br>If the complaint is justified, the [NAME OF AUTHORITY] will issue recommendations and propose measures to the federal government or relevant entities to address the identified issues.<br><br>For more information on the complaints procedure: <a class="green-one" href="https://LINK" target=_extFFG">https://LINK</a>',
            }
          ],            
          about: 'About',
          aboutContent: [
            { header: 'OERhub as a search engine',
              description: 'The OERhub is a search engine for open educational resources (OER).<br><br><b>The OERhub</b><br>Via OERhub, OER can be searched for and then either be reused or processed. Thus, the OERhub makes it easier for teachers to find OER beyond the local technical infrastructures (e.g. online archives such as repositories).<br>The OERhub as an open source project is available at the following link: [LINK]<br><br><b>Context of origin: the ‘Open Education Austria Advanced’ project</b><br>The OERhub was developed as a prototype during the ‘Open Education Austria’ project (2016- 2018) and was made ready for product maturity during the ‘Open Education Austria Advanced’ project (2020-2024).',
            }
          ],
          history: 'Version History',
          historyContent: [
            { header: '1.0.0',
              description: 'This oerhub-ce is based on production release v2.1.3'
            },
          ],
          alBtnMarkFavorite: 'Mark Favorite',
          alNoFavorit: 'No Favorite',
          alIsFavorit: 'Marked as Favorite',
          alPaginationBottom: 'Bottom Nav in Results',
          alPageSelectBottom: 'Bottom Page Selcet',
          alPaginationTop: 'Top Nav in Results',
          alPageSelectTop: 'Top Nav Page Select',
        },
        de: {
          favorites: 'Favoriten',
          search: 'Suche',
          discipline: 'Disziplin',
          learningRT: 'Material',
          language: 'Sprache',
          licence: 'Lizenz',
          aboutLicence: 'Über Creative Commons Lizenzen',
          ccUrl: 'https://creativecommons.org/licenses/?lang=de',
          moreInfo: 'weitere Informationen',
          date: 'Datum',
          source: 'Quelle',
          imprint: 'Impressum',
          imprintContent: [
            { header: 'Betreiberin des OERhub',
              description: 'XXXX XXXX<br>Straße X<br>XXXX Xxxx'
            },            
            { header: 'Urheberrecht',
              description: 'Der Quellcode des OERhub ist als Open Source mit Apache 2.0 Lizenz veröffentlicht. Die Erstellung, die Verwendung und die nicht kommerzielle Weitergabe von Kopien in elektronischer oder ausgedruckter Form sind erlaubt, wenn die Quelle angegeben wird.<br><br>Alle gefundenen und angezeigten OER-Objekte aus den angebundenen Repositorien enthalten Angaben zu den jeweiligen Urheber*innen und Lizenzangaben, die zu beachten sind.'
            },
            { header: 'Haftung',
              description: 'Sämtliche Texte auf dem OERhub wurden sorgfältig geprüft. Dessen ungeachtet kann keine Garantie für die Richtigkeit, Vollständigkeit und Aktualität der Angaben übernommen werden. Die Haftung für die gefundenen OER-Objekte aus den angebundenen Systemen liegt bei der jeweiligen Quelle.'
            }
          ],
          favsDesc: 'Die Favoriten werden als Cookies gespeichert und sind daher nur auf diesem Gerät gesichert. Rufen Sie den OERhub auf einem anderen Gerät auf, können Sie nicht auf Ihre gespeicherten Favoriten zugreifen.',
          favsNotExist: 'Es sind keine Favoriten auf diesem Gerät gespeichert!',
          mediaType: 'Medium',
          sponsor: 'Fördergeber',
          partner: 'Projektpartner von Open Education Austria Advanced:',
          searchTooltip: 'Wie funktioniert die Suche?',
          heading: 'Open Educational Resources (OER) suchen und finden',
          description1:
            'OERhub - Suchmaschine für offene Bildungsressourcen',
          description2:
            '',
          description3:
            '',
          contact: 'Kontakt',
          contactContent: [
            { header: 'Technischer Support',
              description: '',
              person: [ { contact: '<b>Max Mustermann</b><br>Details' } ]
            }
          ],
          disclaimer: 'Disclaimer',
          disclaimer1: 'Aktuell und Zukunft',
          disclaimer2: 'Uns ist es wichtig, dass Sie schnell jene OER finden, nach denen Sie suchen. Deshalb achten wir im Zuge der Entwicklung des OERhub besonders auf die User*innen-freundliche Anzeige der uns gelieferten Metadaten. Hierbei arbeiten wir mit den an den OERhub angebundenen Repositorien zusammen, um Ihnen das bestmögliche Suchergebnis zu liefern.<br><br>Aktuell an den OERhub angebunden sind die OER-Repositorien der Universität Wien, Universität Graz, Univeristät Innsbruck, Technischen Universität Graz sowie die österreichische MOOC-Plattform iMooX und das Archivsystem des Projektes DigiFit4All.<br><br>Im Laufe des Projekts werden zudem alle Entwicklungen rund um den OERhub als Open Source Produkte frei zur Verfügung gestellt.',
          dataProtection: 'Datenschutz',
          project: 'Projekt',
          home: 'Home',
          faq: 'FAQ',
          faqContent: [
            { header: 'Das Konzept des OERhub',
              description: [ { subheader: '', text: 'Lehrende können nach dem Ownerprinzip in einem der angebundenen institutionellen Archivsysteme ihre OER ablegen und freigeben. Durch den OERhub werden diese lokal gespeicherten OER für die breite Nutzung über die eigene Institution hinaus erschlossen. Damit trägt der zentrale OERhub für OER aus dem Hochschulbereich zur nationalen, aber auch internationalen Sichtbarkeit der Lehre österreichischer Hochschulen bei. Konzeptionell wird ein dezentraler Ansatz verfolgt, die Hochschulen tragen weiterhin Verantwortung für ihre lokalen Infrastrukturen (Produktionsabläufe, Archivierung). Der OERhub folgt den FAIR Data Prinzipien und kann auf Grund seiner modularen Architektur und offenen Schnittstellen leicht um weitere Hochschulen erweitert werden. Der OERhub ist mit seiner Anbindung an österreichische Universitäten auch DSGVO-konform im Umgang mit Daten.' } ]
            },
            { header: 'Grundsätze des OERhubs',
              description: [ { subheader: '', text: 'In Anlehnung an die European Open Science Cloud (EOSC) (European Open Science Cloud, 2020) und die internationalen Standards bezüglich Handhabung von Forschungsdaten orientiert sich der OERhub an den FAIR Data-Prinzipien. Auf Basis dieser Grundsätze für die nachhaltige Nutzung von Forschungsdaten sollen Forschungsdateninfrastrukturen im Rahmen der Entwicklung ihrer Services implementiert werden. Auf diesen Prinzipien basieren die Voraussetzungen für die Anbindung eines Quellsystems interessierter Hochschulen an den OERhub, da dieser aufgrund seiner technologischen Architektur leicht erweiterbar und somit «open for collaboration» bei entsprechender technischer Überlieferung der Voraussetzungen ist.' } ]
            },
            { header: 'Voraussetzungen und Vorgaben für eine Anbindung eines Repositoriums an den OERhub',
              description: [ { subheader: '', text: '<ul class="list-inside list-decimal"><li>Als erste Voraussetzung müssen die Metadaten im LOM-Schema an den OERHub geliefert werden. Dabei sind die Felder «Titel», «Autor*in», «Datum» und die Information zur Lizenz Pflicht. Damit gefundene OER über die Facetten gefiltert werden können, braucht es Informationen über die Disziplin - beschrieben über die ÖFOS (Statistik Austria, 2017) - und den Medientypen (MIME-Type). Eine aussagekräftige Beschreibung der didaktischen Einbettung des Lernobjekts erhöht zusätzlich die Qualität der Suche.</li><li>Die zweite Voraussetzung stellt der persistente Link als Verweis auf eine Landingpage dar. Auf dieser sind alle relevanten Information und der Download des Lehr-/Lernobjekts zu finden.</li><li>Als dritte Voraussetzung muss das Objekt selbst mit einer offenen Creative Commons Lizenz angeboten werden.</li></ul>Den TwoPager als Zusammenfassung finden Sie zum Download hier: <a class="green-one" href="https://phaidra.univie.ac.at/detail/o:2110159" target="_extWindow">TwoPager</a>' } ]
            },
            { header: 'Schnittstellen für die Anbindung an den OERhub',
              description: [ { subheader: '', text: 'Die Anbindung für Quellsysteme (dezentrale Hochschulrepositorien) ist aufgrund der offenen Architektur des OERhub auf unterschiedliche Arten möglich. Es kann hier zwischen der OAI-PMH-Schnittstelle, der Application Programming Interfaces (API) des OERhub und weiteren Conntectoren frei gewählt werden.' } ]
            }                                         
          ],          
          resultsFor: 'Ergebnisse für',
          itemFrom: 'Zeige',
          itemTo: 'bis',
          toPress: 'Drucken',
          sortBy: 'Sortiert nach: ',
          author: 'Autor*in',
          uploadDate: 'Hochgeladen am',
          updateDate: 'Zuletzt aktualisiert am',
          loading: 'Einen Moment bitte. Ihre Ergebnisse werden geladen…',
          noSearchResults: 'Ihre Suche ergab leider keine Treffer.',
          back: 'Zurück',
          continue: 'Weiter',
          btnJumpTop: 'Oben',
          btnJumpBottom: 'Ende',          
          seekDiscipline: 'Disziplin suchen',
          seekLearningRT: 'Material suchen',
          seekLanguage: 'Sprache suchen',
          reset: 'Zurücksetzen',
          save: 'Anwenden',
          today: 'Heute',
          lastWeek: 'Letzte Woche',
          lastMonth: 'Letzter Monat',
          lastYear: 'Letztes Jahr',
          metaData: 'Metadaten',
          metaDataDescription: 'Zu diesem Eintrag gibt es folgende zusätzlichen Informationen:',
          report: 'Eintrag melden',
          reportExplanation: 'Bitte nennen Sie uns den Grund, warum Sie diesen Eintrag melden möchten.',
          copy: 'Link Quelle kopieren',
          entries: 'Einträge',
          titleAsc: 'Titel A - Z',
          titleDesc: 'Titel Z - A',
          uploadDateAsc: 'Uploaddatum: aufsteigend',
          uploadDateDesc: 'Uploaddatum: absteigend',
          scoreAsc: 'Relevanz: aufsteigend',
          scoreDesc: 'Relevanz: absteigend',
          remove: 'Entfernen',
          customDate: 'Zeitraum',
          from: 'Von',
          to: 'Bis',
          descriptionLicence: 'CC = Creative Commons, BY = Namensnennnung, NC = Nicht kommerziell, ND = keine Bearbeitung, SA = Weitergabe unter gleichen Bedingungen',
          favoriteTooltip: 'Favorit markieren',
          cancel: 'Abbrechen',
          send: 'Abschicken',
          resetFilters: 'Filter löschen',
          copied: 'Link Quelle kopiert',
          welcomeHead1: 'Willkommen!',
          isAuthorisedHead1: 'Sie sind erfolgreich Angemeldet',
          isAuthorisedDecision: 'Hier können Sie sich ausloggen oder zur Suche... ',
          lnkLogout: 'Log out',
          lnkSearch: 'Zur Suche',
          askPaswordHead1: 'Log in',
          askPasswordTxt: 'Bitte das Passwort ...',
          hintPassword: 'Passwort ...',
          btnPassword: 'Log in',
          btnReset: 'Entferne Suchbegriff',
          btnSearch: 'Suchen',
          descriptionSearch: 'Die eingegebenen Wörter im Textfeld suchen nach Autor, Titel oder Beschreibung. Die gefundenen Resultate können im Anschluss über die Filter-Boxen verfeinert werden. ',
          jsonExport: 'Export als JSON',
          accessibility: 'Barrierefreiheit',
          accessibilityContent: [
            { header: 'Erklärung zur Barrierefreiheit',
              description: 'Bei der Implementierung der OERhub Community Edition v. 1.0. war man bemüht, den OERhub im Einklang mit dem Web-Zugänglichkeits-Gesetz (WZG) idgF zur Umsetzung der Richtlinie (EU) 2016/2102 des Europäischen Parlaments und des Rates vom 26. Oktober 2016 über den barrierefreien Zugang zu den Websites und mobilen Anwendungen öffentlicher Stellen (Amtsblatt L 327 vom 2.12.2016, S. 1) barrierefrei zugänglich zu machen. D<br><br>Diese Erklärung zur Barrierefreiheit gilt für die Website www.example.at',
            },
            { header: 'Stand der Vereinbarkeit mit den Anforderungen',
              description: 'Die Websites sind wegen der im Folgenden dargelegten Unvereinbarkeiten und Ausnahmen teilweise mit den Richtlinien für barrierefreie Webinhalte vereinbar.<br><br>Die zugrundeliegenden Kriterien basieren auf WCAG 2.1 Konformitätsstufe AA bzw. dem Europäischen Standard EN 301 549 V3.1.2 (PDF).<br><br>Punkt 9.6 WCAG Konformitätsanforderungen der EN 301 549 ist nicht erfüllt, da die WCAG 2.1 Level AA nur teilweise erfüllt sind.',
            },
            { header: 'Nicht barrierefreie Inhalte',
              description: '<ul class="list-inside list-disc"><li>Mobile Inhalte werden bei Vergrößerung ab 150% zum Teil fehlerhaft dargestellt</li><li>Link-Beschreibungen sind nicht durchgängig WCAG konform</li><li>Beschriftungen von User Interface Elementen sind zum Teil nicht WCAG konform</li><li>Fremdsprachige Textpassagen sind zum Teil nicht gekennzeichnet</li><li>Bestimmte überlagernde Bereiche bleiben geöffnet, wenn der Tastaturfokus weiter bewegt wird und können nicht per Tastatur geschlossen werden</li><li>Der Suchbereich ist nicht semantisch markiert</li></ul>',
            },
            { header: 'Folgende Inhalte fallen nicht in den Anwendungsbereich der anwendbaren Rechtsvorschriften',
              description: 'Inhalte von Dritten, die nicht im Einflussbereich der Betreiberin des OERhub [NAME] liegen, sind von der Richtlinie (EU) 2016/2102 ausgenommen. Für diese Inhalte Dritter kann bezüglich der Vereinbarkeit mit den Barrierefreiheitsbestimmungen keine Aussage getroffen werden.',
            },
            { header: 'Erstellung dieser Erklärung zur Barrierefreiheit',
              description: 'Diese Erklärung wurde am 11. April 2023 erstellt. Letzte Aktualisierung: 1. Dezember 2024.<br><br>Die Bewertung der Vereinbarkeit der Websites mit dem Webzugänglichkeitsgesetz zur Umsetzung der Anforderungen der Richtlinie (EU) 2016/2102 erfolgte in Form eines externen Accessibility Audits nach WCAG 2.1 im Konformitätslevel AA im Oktober 2024.',
            },
            { header: 'Feedback und Kontaktangaben',
              description: 'Wenn Ihnen Barrieren auffallen, die Sie an der Benutzung dieser Website hindert - Probleme, die in dieser Erklärung nicht beschrieben sind, oder schwerer wiegende Mängel in Bezug auf die Einhaltung der Barrierefreiheitsanforderungen -, so bitten wir Sie, uns diese per [KANAL]] mitzuteilen.<br><br>Wir werden Ihre Anfrage prüfen und Sie ehestmöglich kontaktieren.<br><br>Bitte senden Sie sämtliche Mitteilungen und Anregungen an <a class="green-one" href="mailto:office@example.at?subject=barrierefreiheit - beschwerdestelle">office@example.at</a>. Beschreiben Sie das Problem und führen Sie bitte den Bereich an.',
            },
            { header: 'Kontakt',
              description: '[KONTAKTDATEN]',
            },
            { header: 'Durchsetzungsverfahren',
              description: 'Bei nicht zufriedenstellenden Antworten aus oben genannter Kontaktmöglichkeit können Sie sich mittels Beschwerde an [NAME DES AUSFÜHRENDEN ORGANS] wenden.<br>Kontaktformular der Beschwerdestelle <a class="green-one" href="https://LINK" target="_extFFG">https://LINK</a><br><br>Diese Beschwerden werden von der [NAME DES AUSFÜHRENDEN ORGANS] dahingehend geprüft, ob sie sich auf Verstöße gegen die Vorgaben des Web-Zugänglichkeits-Gesetzes, insbesondere Mängel bei der Einhaltung der Barrierefreiheitsanforderungen, durch den Bund oder einer ihn zuordenbaren Einrichtung beziehen.<br><br>Sofern die Beschwerde berechtigt ist, hat die [NAME DES AUSFÜHRENDEN ORGANS] dem Bund oder den betroffenen Rechtsträgern Handlungsempfehlungen auszusprechen und Maßnahmen vorzuschlagen, die der Beseitigung der vorliegenden Mängel dienen.<br><br>Weitere Informationen zum Beschwerdeverfahren <a class="green-one" href="https://LINK" target=_extFFG">https://LINK</a>',
            }
          ],
          about: 'Über',
          aboutContent: [
            { header: 'OERhub als Suchmaschine',
              description: 'Der OERhub ist eine Suchmaschine für offene Bildungsressourcen - Open Educational Resources (OER)<br><br><b>Der OERhub</b><br>Im OERhub können OER gesucht und gefunden werden, um daraufhin wiederverwendet /verarbeitet zu werden. So erleichtert der OERhub über lokale technische Infrastrukturen (z. B. Online-Archive wie Repositorien) hinweg die Auffindbarkeit von OER für Lehrende.<br>Der OERhub als Open Source Projekt ist unter folgendem Link verfügbar: <a class="green-one" href="https://gitlab.phaidra.org/oerhub-ce/" target="_extFFG">https://gitlab.phaidra.org/oerhub-ce/</a><br><br><b>Entstehungskontext:“</b><br>Der OERhub wurde im Rahmen des Projekts „Open Education Austria“ (2016-2018) prototypisch entwickelt und im Rahmen des Projekts „Open Education Austria Advanced“ (2020-2024) zur Produktreife gebracht.'
            }
          ],
          history: 'Versionshistorie',
          historyContent: [
            { header: '1.0.0',
              description: 'Die oerhub-ce basiert auf der Produktionsversion v2.1.3'
            },            
          ],
          alBtnMarkFavorite: 'Markiere als Favorit',
          alNoFavorit: 'kein Favorit',
          alIsFavorit: 'markiert als Favorit',
          alPaginationBottom: 'Navigation in Resultaten unten',
          alPageSelectBottom: 'Seitenauswahl unten',
          alPaginationTop: 'Navigation in Resultaten open',
          alPageSelectTop: 'Seitenauswahl oben',                 
        },
      },
    },
  },
}
