const axios = require('axios')

exports.defaultSearch = async (req, res) => {
    try {
        const { query, disciplines, learningRTs, languages, licences, mediaTypes, sources, dateRange, sort, startDate, endDate } = req.body
        // query, page, size, 
        let from = 0
        let page = req.body.page
        let size = req.body.size        
        if (!page) {
            page = 0
        }
        if (!size) {
           size = 10
        }
        from = page * size

        const customDateQuery = {
            bool: {
                should: {
                    range: {
                        oea_classification_03: {},
                    },
                },
            },
        }

        const lowerQuery = query.toLowerCase()
        const queryBuilder = {
            bool: 
            {
                must: 
                [
                    {
                        bool: 
                        {
                            should: 
                            [
                                {
                                    multi_match: 
                                    {
                                        query: lowerQuery,
                                        fields: ['oea_title^2', 'oea_title.de^2.5', 'oea_title.en^1.5', 'oea_authors^0.5', 'oea_abstract', 'oea_abstract.de^2.5', 'oea_abstract.en^1.5' ],
                                        operator: 'and',
                                        fuzziness: 'AUTO:3,7',
                                        prefix_length: '2'
                                    }
                                },
                                {
                                    wildcard: 
                                    {
                                        //'oea_abstract': { value: lowerQuery + '*' }
                                        'oea_abstract': { value: lowerQuery }
                                    }
                                },
                                {
                                    nested: 
                                    {
                                        path: 'oea_classification_01',
                                        query: 
                                        {
                                            bool: 
                                            {
                                                should: 
                                                [
                                                    {
                                                        term: { 'oea_classification_01.name_de': { value: lowerQuery, 'case_insensitive': true } }
                                                    },
                                                    {
                                                        term: { 'oea_classification_01.name_en': { value: lowerQuery, 'case_insensitive': true } }
                                                    }
                                                ]
                                            }
                                        }
                                    }
                                },
                                {
                                    nested:
                                    {
                                        path: 'oea_classification_04',
                                        query:
                                        {
                                            bool:
                                            {
                                                should:
                                                [
                                                    {
                                                        term: { 'oea_classification_04.name_de': { value: lowerQuery, 'case_insensitive': true } }
                                                    },
                                                    {
                                                        term: { 'oea_classification_04.name_en': { value: lowerQuery, 'case_insensitive': true } }
                                                    }
                                                ]
                                            }
                                        }
                                    }
                                },
                                {
                                    nested:
                                    {
                                        path: 'oea_classification_06',
                                        query:
                                        {
                                            bool:
                                            {
                                                should:
                                                [
                                                    {
                                                        term: { 'oea_classification_06.name_de': { value: lowerQuery, 'case_insensitive': true } }
                                                    },
                                                    {
                                                        term: { 'oea_classification_06.name_en': { value: lowerQuery, 'case_insensitive': true } }
                                                    }
                                                ]
                                            }
                                        }
                                    }
                                }
                            ]
                        }
                    }
                ],
                must_not: { term: { 'oea_valid': 'false' } },
            },
        }

        if (mediaTypes && mediaTypes.length > 0) {
            // const mediaTypesQuery = mediaTypes.map(licence => ({ match: { oea_classification_05: licence } }))
            const mediaTypesQuery = mediaTypes.map(mediaType => ({ match: { oea_classification_05: mediaType } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    bool: {
                        should: mediaTypesQuery,
                    },
                },
            ]
        }

        if (disciplines && disciplines.length > 0) {
            const disciplinesQuery = disciplines.map(discipline => ({ match: { 'oea_classification_01.id': discipline.id } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    nested: {
                        path: 'oea_classification_01',
                        query: { bool: { should: disciplinesQuery } },
                    },
                },
            ]
        }

        if (learningRTs && learningRTs.length > 0) {
            const learningRTsQuery = learningRTs.map(learningRT => ({ match: { 'oea_classification_04.id': learningRT.id } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    nested: {
                        path: 'oea_classification_04',
                        query: { bool: { should: learningRTsQuery } },
                    },
                },
            ]
        }

        if (languages && languages.length > 0) {
            const languagesQuery = languages.map(language => ({ match: { 'oea_classification_06.id': language.id } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    nested: {
                        path: 'oea_classification_06',
                        query: { bool: { should: languagesQuery } },
                    },
                },
            ]
        }

        if (licences && licences.length > 0) {
            const licencesQuery = licences.map(licence => ({ match: { oea_classification_02: licence } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    bool: {
                        should: licencesQuery,
                    },
                },
            ]
        }

        // Substracts current date from input start date which return millisecond, which are after converted to days
        // After that depending if result is greater than zero or not returns a query for elasticsearch ex. 'now-30d/d'
        if (startDate) {
            const startDateDays = Math.floor((new Date() - new Date(startDate)) / 1000 / 60 / 60 / 24)
            const startQuery = startDateDays > 0 ? `now-${startDateDays}d/d` : `now+${startDateDays * -1}d/d`

            customDateQuery.bool.should.range.oea_classification_03 = { ...customDateQuery.bool.should.range.oea_classification_03, gte: startQuery }
        }

        if (endDate) {
            const endDateDays = Math.floor((new Date() - new Date(endDate)) / 1000 / 60 / 60 / 24)
            const endQuery = endDateDays > 0 ? `now-${endDateDays}d/d` : `now+${endDateDays * -1}d/d`

            customDateQuery.bool.should.range.oea_classification_03 = { ...customDateQuery.bool.should.range.oea_classification_03, lte: endQuery }
        }

        if (startDate || endDate) {
            queryBuilder.bool.must = [...queryBuilder.bool.must, customDateQuery]
        }

        if (dateRange && dateRange !== 'customDate') {
            const dateRangeQuery = { range: { oea_classification_03: { gte: dateRange } } }

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    bool: {
                        should: dateRangeQuery,
                    },
                },
            ]
        }

        if (sources && sources.length > 0) {
            const sourcesQuery = sources.map(source => ({ match: { _index: source } }))

            queryBuilder.bool.must = [
                ...queryBuilder.bool.must,
                {
                    bool: {
                        should: sourcesQuery,
                    },
                },
            ]
        }

        let requestBody = {
            query: queryBuilder,
            from,
            size,
            highlight: {
                fields: {   
                    'oea_abstract': {},
                    'oea_title': {},
                    'oea_authors': {},
                    'oea_classification_01.name_en': {},
                    'oea_classification_01.name_de': {},
                    'oea_classification_04.name_en': {},
                    'oea_classification_04.name_de': {},
                    'oea_classification_06.name_en': {},
                    'oea_classification_06.name_de': {},
                }
            },
            aggregations: {
                facet_oea_classification_05: { terms: { field: 'oea_classification_05' } },
                facet_oea_classification_01: {
                    nested: { path: 'oea_classification_01' },
                    aggregations: {
                        id: {
                            terms: { field: 'oea_classification_01.id', size: 123 },
                            aggregations: { name_de: { terms: { field: 'oea_classification_01.name_de' } }, name_en: { terms: { field: 'oea_classification_01.name_en' } } },
                        },
                    },
                },
                facet_oea_classification_04: {
                    nested: { path: 'oea_classification_04' },
                    aggregations: {
                        id: {
                            terms: { field: 'oea_classification_04.id', size: 123 },
                            aggregations: { name_de: { terms: { field: 'oea_classification_04.name_de' } }, name_en: { terms: { field: 'oea_classification_04.name_en' } } },
                        },
                    },
                },
                facet_oea_classification_06: {
                    nested: { path: 'oea_classification_06' },
                    aggregations: {
                        id: {
                            terms: { field: 'oea_classification_06.id', size: 123 },
                            aggregations: { name_de: { terms: { field: 'oea_classification_06.name_de' } }, name_en: { terms: { field: 'oea_classification_06.name_en' } } },
                        },
                    },
                },
                facet_oea_classification_02: { terms: { field: 'oea_classification_02', size: 23 } },
                facet_oea_classification_03: {
                    date_range: {
                        field: 'oea_classification_03',
                        keyed: true,
                        ranges: [
                            { from: 'now/d', key: 'today' },
                            { from: 'now-7d/d', key: 'last_week' },
                            { from: 'now-1M/d', key: 'last_month' },
                            { from: 'now-1y/d', key: 'last_year' },
                        ],
                    },
                },
                facet__index: { terms: { field: '_index' } },
            },
        }

        if (sort && sort.type === 'date') {
            requestBody = {
                ...requestBody,
                sort: [
                    {
                        oea_classification_03: {
                            order: sort.order,
                            mode: 'min',
                        },
                    },
                ],
            }
        }

        // show requested query in console
        console.log(JSON.stringify(requestBody, null, 4))

        const resp = await axios.post('', requestBody)

        const disciplinesCounter = {}
        const learningRTsCounter = {}
        const languagesCounter = {}
        const licenceCounter = {}
        const mediaTypeCounter = {}
        const sourceCounter = {}

        const disciplinesArr = resp.data.aggregations.facet_oea_classification_01.id.buckets.map(discipline => {
            if (!disciplinesCounter[discipline.key]) {
                disciplinesCounter[discipline.key] = 1
                return {
                    id: discipline.key,
                    name_en: discipline.name_en.buckets[0].key,
                    name_de: discipline.name_de.buckets[0].key,
                }
            }
        })

        const learningRTsArr = resp.data.aggregations.facet_oea_classification_04.id.buckets.map(learningRT => {
            if (!learningRTsCounter[learningRT.key]) {
                learningRTsCounter[learningRT.key] = 1
                return {
                    id: learningRT.key,
                    name_en: learningRT.name_en.buckets[0].key,
                    name_de: learningRT.name_de.buckets[0].key,
                }
            }
        })

        const languagesArr = resp.data.aggregations.facet_oea_classification_06.id.buckets.map(language => {
            if (!languagesCounter[language.key]) {
                languagesCounter[language.key] = 1
                return {
                    id: language.key,
                    name_en: language.name_en.buckets[0].key,
                    name_de: language.name_de.buckets[0].key,
                }
            }
        })

        const licencesArr = resp.data.aggregations.facet_oea_classification_02.buckets.map(licence => {
            if (!licenceCounter[licence.key]) {
                licenceCounter[licence.key] = 1
                return licence.key
            }
        })

        const mediaTypesArr = resp.data.aggregations.facet_oea_classification_05.buckets.map(mediaType => {
            if (!mediaTypeCounter[mediaType.key]) {
                mediaTypeCounter[mediaType.key] = 1
                return mediaType.key
            }
        })

        const sourcesArr = resp.data.aggregations.facet__index.buckets.map(source => {
            if (!sourceCounter[source.key]) {
                sourceCounter[source.key] = 1
                return source.key
            }
        })

        // Sorts an array of the disciplines based on a "Name_de" object property
        const sortedDisciplines = disciplinesArr.sort((a, b) => (a.name_de > b.name_de ? 1 : b.name_de > a.name_de ? -1 : 0))
        const sortedLearningRTs = learningRTsArr.sort((a, b) => (a.name_de > b.name_de ? 1 : b.name_de > a.name_de ? -1 : 0))
        const sortedLanguages = languagesArr.sort((a, b) => (a.name_de > b.name_de ? 1 : b.name_de > a.name_de ? -1 : 0))

        res.send({ data: resp.data, disciplines: sortedDisciplines, learningRTs: sortedLearningRTs, languages: sortedLanguages, licences: licencesArr, mediaType: mediaTypesArr, sources: sourcesArr })
    } catch (err) {
        res.send(err)
        console.log(err)
    }
}

exports.findArticleById = async (req, res) => {
    try {
        const { id } = req.params
        const query = { query: { bool: { must: [{ term: { _id: id } }] } } }
        const resp = await axios.post('', query)

        res.send({ data: resp.data.hits.hits[0] })
    } catch (err) {
        console.log(err)
        res.send(err)
    }
}

exports.getFavorites = async (req, res) => {
    try {
        // console.log('getFavorites ids:' + req.body.ids)

        const ids = req.body.ids
        let page = req.body.page
        let size = req.body.size
        let from = 0
        if (!page) {
            page = 0
        } 
        if (!size) {
           size = 10
        }
        from = page * size

        // console.log('getFavorites: size, page - ' + size + ', ' +  page)

        const queryBuilder = {
            query: {
                ids: {
                    values: [],
                },
            },
            from,
            size
        }

        ids.forEach(id => (queryBuilder.query.ids.values = [...queryBuilder.query.ids.values, id]))
        // console.log(queryBuilder);
        const resp = await axios.post('', queryBuilder)
        res.send({ data: resp.data })
    } catch (err) {
        console.log(err)
        res.send(err)
    }
}

exports.findArticlesByAuthor = async (req, res) => {
    try {
        // console.log(req.params)

        const name = req.params.name
        let page = req.params.page
        let size = req.params.size
        let from = 0
        if (!page) {
            page = 0
        }
        if (!size) {
           size = 10
        }
        from = page * size

        // console.log('name, size, page' + name + ', ' + size + ', ' +  page)

        var noDotsAndOthers = name.replace(/[,;\-\_\']/g, ' ')
        noDotsAndOthers = noDotsAndOthers.replace(/(\.\s)/g, ' ')
        noDotsAndOthers = noDotsAndOthers.replace(/[\u007C\u2014\u2013\(\)]/g, '')
        noDotsAndOthers = noDotsAndOthers.replace(/ +/g, ' ')
        const lowerBlankName = noDotsAndOthers.toLowerCase()
        const query = { 
            query: { 
                bool: { 
                    must: { 
                        query_string: {
                            fields: [ 'oea_authors' ],
                            query: '"' + lowerBlankName + '"'
                        }
                    }
                } 
            },
            from,
            size
        }
        // show requested query in console
        console.log(JSON.stringify(query, null, 4))
        const resp = await axios.post('', query)
        res.send({ data: resp.data })
    } catch (err) {
        console.log(err)
        res.send(err)
    }
}
exports.testGet = async (req, res) => {
    try {
        const ok = 'Okay'
        console.log(req.params)
        res.send({ data: ok })
    } catch (err) {
        console.log(err)
        res.send(err)
    }
}
exports.testPost = async (req, res) => {
    try {
        const ok = 'Okay'
        console.log(req.body)
        res.send({ data: ok })
    } catch (err) {
        console.log(err)
        res.send(err)
    }
}
