package App::Locker;

use strict;
use warnings;

use Carp;
use Data::Dumper;

use Fcntl qw/:flock/;
use File::Basename;

our @ISA = qw(
  Exporter
);

our @EXPORT = qw(
  &get_lock
  &release_lock
);

sub get_lock {
  my ($lockfile, $nolockmsg) = @_;

  # sanity
  croak "no lockfile given" unless $lockfile;
  croak "no nolockmsg given" unless $nolockmsg;
  croak "no newline at end of nolockmsg" unless $nolockmsg =~ m{\n$};

  open my $fh, '>', $lockfile or croak "no open at |$lockfile|, |$!|";
  # has to die to prevent backtrace that would be included in croak
  flock( $fh, LOCK_EX|LOCK_NB ) or die $nolockmsg;

  return \*$fh;
}

sub release_lock {
  my ($fh) = @_;

  # sanity
  croak "no fh given" unless $fh;

  flock( $fh, LOCK_UN ) or croak "no flock LOCK_UN at |$fh|, |$!|";

  return;
}

1;

__END__

