#!/usr/bin/env perl

# receive messages from queues

use strict;
use warnings;

use Data::Dumper;

use YAML::Syck;
use FindBin;
use lib "$FindBin::Bin/lib";
use App::Logger;
use App;
use Time::HiRes qw/sleep/;

# config
my $daemon = YAML::Syck::LoadFile("$FindBin::Bin/etc/daemon/config.yml");

# settings
$Data::Dumper::Indent = 2;

# logger
my $logger = App::Logger->new(
  file => $FindBin::Bin.'/'.$daemon->{ctrl}->{log}->{path}.'/'.$daemon->{ctrl}->{log}->{filename},
  debug => defined $daemon->{ctrl}->{debug} ? $daemon->{ctrl}->{debug} : 1,
  verbosity => defined $daemon->{ctrl}->{verbosity} ? $daemon->{ctrl}->{verbosity} : 2,
);

$logger->info('start');

# control
$main::term = 0;
my $sig_term = sub { $main::term = 1; };
local $SIG{INT}  = $sig_term;
local $SIG{TERM} = $sig_term;

eval {

  # settings
  my $sleep = $daemon->{ctrl}->{sleep} || 10;
  my $dryrun = defined $daemon->{ctrl}->{dryrun} ? $daemon->{ctrl}->{dryrun} : 0;

  $logger->debug("daemon ctrl sleep |$sleep|");
  $logger->debug("daemon ctrl dryrun |$dryrun|");

  LOOP:
  while ( !$main::term ) {

    $logger->info('alive and looping', 2);

    # config
    my $payload = YAML::Syck::LoadFile("$FindBin::Bin/etc/queues/payload.yml");

    $logger->info('start processing', 1);

    # ctrl config
    my $ctrl = $payload->{ctrl};
    $logger->debug('ctrl ' . Dumper( $ctrl ) );

    # queues config
    my $queues = $payload->{queues};
    $logger->debug('queues ' . Dumper( $queues ) );

    {
      # settings
      local $Data::Dumper::Indent = 0;

      # new App for queues
      $logger->info('app App->new', 2);
      my $app = App->new(
        ctrl => $ctrl,
        queues => $queues,
      );

      # workout queues
      unless ( $dryrun ) {
        $logger->info('app start', 1);
        my $ret = $app->run();
        if ( $ret ) {
          $logger->info('app error', 1);
        }
        else {
          $logger->info('app done', 1);
        }
      }
    }

    $logger->info('done processing', 1);

    # no SIG via main::term received
    if ( !$main::term ) {
      $logger->info("sleep |$sleep|", 1);
      sleep $sleep;
      $logger->info('awake', 2);
      $logger->info('about to loop', 2);
    }
    # SIG via main::term received
    else {
      $logger->warning('SIG via main::term received', 2);
    }

  } # while ( !$main::term )

}; # eval
if ( $@ ) {
  my $syntax_error_message = $@;
  chomp $syntax_error_message;
  $logger->fatal("daemon died |$syntax_error_message|");
  die $syntax_error_message;
}
else {
  $logger->info('daemon gracefully stopped');
}

$logger->info('stop');

exit(0);

