package App::Type::OAIIngest_DC;

# workout job type OAIIngest_DC

use strict;
use warnings;

use Carp;
use Data::Dumper;

use FindBin;
use lib "$FindBin::Bin/../../";
use Encode;
use App::Logger;
use JSON::XS;
use LWP::Simple;
use Text::CSV_XS;
# use XML::Simple; Not Used

use utf8;

sub new {
  my ($class, %args) = @_;

  my $self = {};
  # mandatory
  $self->{_cfg} = $args{cfg} || croak "no cfg given";

  bless($self, $class);

  $self->_init();
  $self->_prepare_oefos();

  return $self;
}

sub _init {
  my ($self) = @_;
  croak "_init is private" if caller() ne __PACKAGE__;

  # new logger
  $self->{_logger} = App::Logger->new(
    file => $FindBin::Bin.'/'.$self->{_cfg}->{log}->{path}.'/'.$self->{_cfg}->{log}->{filename},
    debug => defined $self->{_cfg}->{debug} ? $self->{_cfg}->{debug} : 1,
    verbosity => defined $self->{_cfg}->{verbosity} ? $self->{_cfg}->{verbosity} : 2,
  );

  $self->{_logger}->debug('_cfg ' . Dumper( $self->{_cfg} ) );

  # config
  $self->{_config} = YAML::Syck::LoadFile("$FindBin::Bin/etc/targets/oaiingest_dc/config.yml");
  $self->{_logger}->debug('_config ' . Dumper( $self->{_config} ) );

  return;
}

sub _prepare_oefos {
  my ($self) = @_;
  croak "_prepare_oefos is private" if caller() ne __PACKAGE__;

  ## settings
  # shortcut
  my $logger = $self->{_logger};

  # OEFOS2002_DE
  ## load data
  my $csv_OEFOS2002_DE = Text::CSV_XS->new({
    binary => 1,
    decode_utf8 => 0,
    eol => "\r\n",
    sep_char => ';',
  }) or croak "no new at Text::CSV_XS: ".Text::CSV_XS->error_diag();
  my $file_OEFOS2002_DE = $FindBin::Bin.'/'.$self->{_config}->{fs}->{oefos}->{2002}->{de};
  open my $fh_OEFOS2002_DE, '<', $file_OEFOS2002_DE or croak "no open at file |$file_OEFOS2002_DE|, |$!|";
    $csv_OEFOS2002_DE->column_names( $csv_OEFOS2002_DE->getline($fh_OEFOS2002_DE) );
    my $csv_OEFOS2002_DE_all = $csv_OEFOS2002_DE->getline_hr_all($fh_OEFOS2002_DE);
  close $fh_OEFOS2002_DE or carp "no close at file |$file_OEFOS2002_DE|, |$!|";
#  ## filter Ebene 3, create lookup HASH { Code => Titel }
#  my %csv_OEFOS2002_DE_all_code_titel = map { $_->{Code} => $_->{Titel} } grep { $_->{Ebene} eq 3 } @$csv_OEFOS2002_DE_all;
# TODO: to grep or not to grep
  ## create lookup HASH { Code => Titel }
  my %csv_OEFOS2002_DE_all_code_titel = map { $_->{Code} => $_->{Titel} } @$csv_OEFOS2002_DE_all;
  ## create lookup HASH { Titel => Code }
  my %csv_OEFOS2002_DE_all_titel_code = reverse %csv_OEFOS2002_DE_all_code_titel;
  ## assign
  $self->{_csv_OEFOS2002_DE_all_code_titel} = \%csv_OEFOS2002_DE_all_code_titel;
  $self->{_csv_OEFOS2002_DE_all_titel_code} = \%csv_OEFOS2002_DE_all_titel_code;
  ## log
  $logger->info('scalar keys csv_OEFOS2002_DE_all_code_titel |' . scalar( keys %csv_OEFOS2002_DE_all_code_titel ) . '|', 2);
  $logger->info('scalar keys csv_OEFOS2002_DE_all_titel_code |' . scalar( keys %csv_OEFOS2002_DE_all_titel_code ) . '|', 2);

  # OEFOS2002_EN
  ## load data
  my $csv_OEFOS2002_EN = Text::CSV_XS->new({
    binary => 1,
    decode_utf8 => 0,
    eol => "\r\n",
    sep_char => ';',
  }) or croak "no new at Text::CSV_XS: ".Text::CSV_XS->error_diag();
  my $file_OEFOS2002_EN = $FindBin::Bin.'/'.$self->{_config}->{fs}->{oefos}->{2002}->{en};
  open my $fh_OEFOS2002_EN, '<', $file_OEFOS2002_EN or croak "no open at file |$file_OEFOS2002_EN|, |$!|";
    $csv_OEFOS2002_EN->column_names( $csv_OEFOS2002_EN->getline($fh_OEFOS2002_EN) );
    my $csv_OEFOS2002_EN_all = $csv_OEFOS2002_EN->getline_hr_all($fh_OEFOS2002_EN);
  close $fh_OEFOS2002_EN or carp "no close at file |$file_OEFOS2002_EN|, |$!|";
#  ## filter Ebene 3, create lookup HASH { Code => Titel }
#  my %csv_OEFOS2002_EN_all_code_titel = map { $_->{Code} => $_->{Titel} } grep { $_->{Ebene} eq 3 } @$csv_OEFOS2002_EN_all;
# TODO: to grep or not to grep
  ## create lookup HASH { Code => Titel }
  my %csv_OEFOS2002_EN_all_code_titel = map { $_->{Code} => $_->{Titel} } @$csv_OEFOS2002_EN_all;
  ## create lookup HASH { Titel => Code }
  my %csv_OEFOS2002_EN_all_titel_code = reverse %csv_OEFOS2002_EN_all_code_titel;
  ## assign
  $self->{_csv_OEFOS2002_EN_all_code_titel} = \%csv_OEFOS2002_EN_all_code_titel;
  $self->{_csv_OEFOS2002_EN_all_titel_code} = \%csv_OEFOS2002_EN_all_titel_code;
  ## log
  $logger->info('scalar keys csv_OEFOS2002_EN_all_code_titel |' . scalar( keys %csv_OEFOS2002_EN_all_code_titel ) . '|', 2);
  $logger->info('scalar keys csv_OEFOS2002_EN_all_titel_code |' . scalar( keys %csv_OEFOS2002_EN_all_titel_code ) . '|', 2);

  # OEFOS2012_DE
  ## load data
  my $csv_OEFOS2012_DE = Text::CSV_XS->new({
    binary => 1,
    decode_utf8 => 0,
    eol => "\r\n",
    sep_char => ';',
  }) or croak "no new at Text::CSV_XS: ".Text::CSV_XS->error_diag();
  my $file_OEFOS2012_DE = $FindBin::Bin.'/'.$self->{_config}->{fs}->{oefos}->{2012}->{de};
  open my $fh_OEFOS2012_DE, '<', $file_OEFOS2012_DE or croak "no open at file |$file_OEFOS2012_DE|, |$!|";
    $csv_OEFOS2012_DE->column_names( $csv_OEFOS2012_DE->getline($fh_OEFOS2012_DE) );
    my $csv_OEFOS2012_DE_all = $csv_OEFOS2012_DE->getline_hr_all($fh_OEFOS2012_DE);
  close $fh_OEFOS2012_DE or carp "no close at file |$file_OEFOS2012_DE|, |$!|";
#  ## filter Ebene 4, create lookup HASH { Code => Titel }
#  my %csv_OEFOS2012_DE_all_code_titel = map { $_->{Code} => $_->{Titel} } grep { $_->{Ebene} eq 4 } @$csv_OEFOS2012_DE_all;
# TODO: to grep or not to grep
  ## create lookup HASH { Code => Titel }
  my %csv_OEFOS2012_DE_all_code_titel = map { $_->{Code} => $_->{Titel} } @$csv_OEFOS2012_DE_all;
  ## create lookup HASH { Titel => Code }
  my %csv_OEFOS2012_DE_all_titel_code = reverse %csv_OEFOS2012_DE_all_code_titel;
  ## assign
  $self->{_csv_OEFOS2012_DE_all_code_titel} = \%csv_OEFOS2012_DE_all_code_titel;
  $self->{_csv_OEFOS2012_DE_all_titel_code} = \%csv_OEFOS2012_DE_all_titel_code;
  ## log
  $logger->info('scalar keys csv_OEFOS2012_DE_all_code_titel |' . scalar( keys %csv_OEFOS2012_DE_all_code_titel ) . '|', 2);
  $logger->info('scalar keys csv_OEFOS2012_DE_all_titel_code |' . scalar( keys %csv_OEFOS2012_DE_all_titel_code ) . '|', 2);

  # OEFOS2012_EN
  ## load data
  my $csv_OEFOS2012_EN = Text::CSV_XS->new({
    binary => 1,
    decode_utf8 => 0,
    eol => "\r\n",
    sep_char => ';',
  }) or croak "no new at Text::CSV_XS: ".Text::CSV_XS->error_diag();
  my $file_OEFOS2012_EN = $FindBin::Bin.'/'.$self->{_config}->{fs}->{oefos}->{2012}->{en};
  open my $fh_OEFOS2012_EN, '<', $file_OEFOS2012_EN or croak "no open at file |$file_OEFOS2012_EN|, |$!|";
    $csv_OEFOS2012_EN->column_names( $csv_OEFOS2012_EN->getline($fh_OEFOS2012_EN) );
    my $csv_OEFOS2012_EN_all = $csv_OEFOS2012_EN->getline_hr_all($fh_OEFOS2012_EN);
  close $fh_OEFOS2012_EN or carp "no close at file |$file_OEFOS2012_EN|, |$!|";
#  ## filter Ebene 4, create lookup HASH { Code => Titel }
#  my %csv_OEFOS2012_EN_all_code_titel = map { $_->{Code} => $_->{Titel} } grep { $_->{Ebene} eq 4 } @$csv_OEFOS2012_EN_all;
# TODO: to grep or not to grep
  ## create lookup HASH { Code => Titel }
  my %csv_OEFOS2012_EN_all_code_titel = map { $_->{Code} => $_->{Titel} } @$csv_OEFOS2012_EN_all;
  ## create lookup HASH { Titel => Code }
  my %csv_OEFOS2012_EN_all_titel_code = reverse %csv_OEFOS2012_EN_all_code_titel;
  ## assign
  $self->{_csv_OEFOS2012_EN_all_code_titel} = \%csv_OEFOS2012_EN_all_code_titel;
  $self->{_csv_OEFOS2012_EN_all_titel_code} = \%csv_OEFOS2012_EN_all_titel_code;
  ## log
  $logger->info('scalar keys csv_OEFOS2012_EN_all_code_titel |' . scalar( keys %csv_OEFOS2012_EN_all_code_titel ) . '|', 2);
  $logger->info('scalar keys csv_OEFOS2012_EN_all_titel_code |' . scalar( keys %csv_OEFOS2012_EN_all_titel_code ) . '|', 2);

  return;
}

sub ingestTimeStamp {
  my ($sec,$min,$hour,$mday,$mon,$year,$wday,$yday,$isdst)=localtime(time);
  my $timestamp = sprintf ( "%04d-%02d-%02d %02d:%02d:%02d", $year+1900,$mon+1,$mday,$hour,$min,$sec);
  return $timestamp;
}

sub run {
  my ($self, %args) = @_;

  # args
  $self->{_ua} = $args{ua} || croak "no ua given";
  $self->{_msg} = $args{msg} || croak "no msg given";

  ## settings
  # shortcut
  my $logger = $self->{_logger};

  $logger->info('OAIIngest_DC start', 1);

  # this method can die/croak/confess

  eval {

    $logger->debug('_msg ' . Dumper( $self->{_msg} ), 2);

    $logger->info('OAIIngest_DC workout start', 1);

    $logger->info('prepare metadata', 2);

    # apparently Net::AMQP::RabbitMQ->recv() returns a Perl data structure
    # hence, we have to encode it to UTF-8 before decode_json
    #
    # https://perldoc.perl.org/Encode.html
    #   "Encodes [..] from Perl's internal form into ENCODING"
    # Perl -> UTF-8
    my $body = encode( 'UTF-8', $self->{_msg}->{body} );
    $logger->debug('body ' . Dumper( $body ), 2);

    # decode_xml $body as $item
    $logger->info('decode_xml body', 2);


    ######## NEW IMPLEMENTATION HERE ########
    # here decode the xml-data from the mq
    # do the transformation to json
    #########################################



    # https://perldoc.perl.org/Encode.html
    #   "Encodes [..] from Perl's internal form into ENCODING"
    # Perl -> UTF-8
    my $item = decode_json( $body );
    
    my $id = $item->{pid}; # use $item->{pid} as id
    $logger->info('processing id[' . $id .']', 1);
    # custom filter
    $logger->info('custom filter', 2);

    ## use $item->{dc_title}[0] as oea_title
    $item->{oea_title} = $item->{dc_title}[0];
    ## use $item->{dc_description}[0] as oea_abstract
    $item->{oea_abstract} = $item->{dc_description}[0];
    ## use $item->{dc_creator} elements as oea_authors
    $item->{oea_authors} = $item->{dc_creator};
    ## use $item->{dc_identifier}[-1] as oea_object_direct_link
    $item->{oea_object_direct_link} = $item->{dc_identifier}[-1];

    $item->{oea_ingest} = ingestTimeStamp();

    ## use translated $item->{cmodel} as oea_classification_00
    # set oea_classification_00 (Audio, PDFDocument, Picture, Video, Miscellaneous)
    my $oea_classification_00;
    TYPE:
    for ( $item->{cmodel} ) {
      if (/^Audio$/) {
        $oea_classification_00 = 'Audio';
      }
      elsif (/^PDFDocument$/) {
        $oea_classification_00 = 'Document';
      }
      elsif (/^Picture$/) {
        $oea_classification_00 = 'Picture';
      }
      elsif (/^Video$/) {
        $oea_classification_00 = 'Video';
      }
      else {
        $oea_classification_00 = 'Miscellaneous';
      }
    }
    $item->{oea_classification_00} = $oea_classification_00;

    ## use $item->{dc_subject_eng} elements starting with 'ÖFOS, ', 'ÖFOS 2012, ' as oea_classification_01 this was replaced with
    ## use $item->{dc_subject_eng} elements starting with 'ÖFOS -- ', 'ÖFOS 2012 -- ' as oea_classification_01 NEW in Phaidra
    ## Example: "ÖFOS 2012 -- SOCIAL SCIENCES (5) -- Media and Communication Siences (508)"
    DC_SUBJECT_ENG:
    my $oefos_type = ref($item->{dc_subject_eng});
    my $txt = '';
    my $dc_subject_eng_code = '';
    if ( $oefos_type eq "ARRAY" ) {
      for my $dc_subject_eng ( @{$item->{dc_subject_eng}} ) {
        # ÖFOS 2002
        if ( ($txt, $dc_subject_eng_code) = $dc_subject_eng =~ /^ÖFOS -- (.*)\((\d+)\)$/ ) {
          my $dc_subject_eng_titel = $self->{_csv_OEFOS2002_EN_all_code_titel}->{ $dc_subject_eng_code };
          my $dc_subject_deu_titel = $self->{_csv_OEFOS2002_DE_all_code_titel}->{ $dc_subject_eng_code };
          unless ( $dc_subject_eng_code && $dc_subject_eng_titel && $dc_subject_deu_titel ) {
            push @{$item->{oea_classification_01}}, {
              id => '999999',
              name_de => 'Sonstiges',
              name_en => 'Miscellaneous',
              tag => 'OEFOS2002',
            };
            $logger->warning("problem at OeFOS 2002 dc_subject_eng |$dc_subject_eng|, _msg routing_key |$self->{_msg}->{routing_key}|, pid |$item->{pid}|");
          } else {
            push @{$item->{oea_classification_01}}, {
              id => $dc_subject_eng_code,
              name_de => $dc_subject_deu_titel,
              name_en => $dc_subject_eng_titel,
              tag => 'OEFOS2002',
            };
          }
        }
        # ÖFOS 2012
        elsif ( ($txt, $dc_subject_eng_code) = $dc_subject_eng =~ /^ÖFOS 2012 -- (.*)\((\d+)\)$/ ) {
          my $dc_subject_eng_titel = $self->{_csv_OEFOS2012_EN_all_code_titel}->{ $dc_subject_eng_code };
          my $dc_subject_deu_titel = $self->{_csv_OEFOS2012_DE_all_code_titel}->{ $dc_subject_eng_code };
          unless ( $dc_subject_eng_code && $dc_subject_eng_titel && $dc_subject_deu_titel ) {
            push @{$item->{oea_classification_01}}, {
              id => '999999',
              name_de => 'Sonstiges',
              name_en => 'Miscellaneous',
              tag => 'OEFOS2012',
            };
            $logger->warning("problem at OeFOS 2012 dc_subject_eng |$dc_subject_eng|, _msg routing_key |$self->{_msg}->{routing_key}|, pid |$item->{pid}|");
          } else {
            push @{$item->{oea_classification_01}}, {
              id => $dc_subject_eng_code,
              name_de => $dc_subject_deu_titel,
              name_en => $dc_subject_eng_titel,
              tag => 'OEFOS2012',
            };
          } 
        }
      }
    } else {
      push @{$item->{oea_classification_01}}, {
        id => '999999',
        name_de => 'Sonstiges',
        name_en => 'Miscellaneous',
        tag => 'OEFOS2012',
      };
      $logger->warning("problem at OeFOS 2012 dc_subject_eng | empty |, _msg routing_key |$self->{_msg}->{routing_key}|, pid |$item->{pid}|");
    } 

    ## use first $item->{dc_license} element starting with 'CC BY' as oea_classification_02
    ($item->{oea_classification_02}) = grep { /^CC BY/ } @{$item->{dc_license}};
    if ( $item->{oea_classification_02} eq "" ) {
      $item->{oea_valid} = 'false';
      $item->{oea_unvalid_remark} = 'not a CC license';
    } else {
      $item->{oea_valid} = 'true';
    }
    ## use $item->{created} as oea_classification_03
    $item->{oea_classification_03} = $item->{created};

    # custom delete
    $logger->info('custom delete', 2);

    ## delete conflicting key _id._oid
    ##   mapper_parsing_exception
    ##     "Could not dynamically add mapping for field [_id._oid]. Existing mapping for [_id] must be of type object but found [_id]."
    delete $item->{'_id._oid'};

    ## delete conflicting key dc_date
    ##   mapper_parsing_exception
    ##     illegal_field_value_exception
    ##       "Cannot parse \"1510-15\": Value 15 for monthOfYear must be in the range [1,12]"
    ##     illegal_argument_exception
    ##       "Invalid format: \"1877 (2. Aufl.)\" is malformed at \" (2. Aufl.)\""
    ##     [..]
    delete $item->{dc_date};

    ## delete conflicting key bib_published
    ##   mapper_parsing_exception
    ##     illegal_field_value_exception
    ##       "Cannot parse \"1510-15\": Value 15 for monthOfYear must be in the range [1,12]"
    ##     illegal_argument_exception
    ##       "Invalid format: \"1877 (2. Aufl.)\" is malformed at \" (2. Aufl.)\""
    delete $item->{bib_published};

    {
      # settings
      local $Data::Dumper::Indent = 0;
      $logger->debug('item ' . Dumper( $item ), 2);
    }

    # you might want to investigate on the topic of Elasticsearch 6.x and the removal of mapping types
    my $index = $self->{_msg}->{routing_key};
    ## my $id = $item->{pid}; # use $item->{pid} as id
    my $uri = "http://index:9200/$index/_doc/$id";
    $logger->info("uri |$uri|", 2);

    # encode_json item as $data
    $logger->info('encode_json item', 2);
    my $data = encode_json( $item );

    {
      # settings
      local $Data::Dumper::Indent = 0;
      $logger->debug('data ' . Dumper( $data ), 2);
    }

    $logger->info('req HTTP::Request->new', 2);
    my $req = HTTP::Request->new( 'PUT', $uri );
    $req->header( 'Content-Type' => 'application/json' );
    $req->content( $data );

    $logger->info('ingest start', 2);
    my $res = $self->{_ua}->request( $req );
    if ( !$res->is_success() ) {
      $logger->fatal("no valid response from uri |$uri|, status_line |".$res->status_line()."|, content |".$res->content()."|");
      croak "no valid response from uri |$uri|, status_line |".$res->status_line()."|, content |".$res->content()."|";
    }
    $logger->info('res status_line |'.$res->status_line().'|', 2);
    $logger->info('res content |'.$res->content().'|', 2);
    $logger->info('ingest done', 2);

    $logger->info('OAIIngest_DC workout done', 1);

  }; # eval
  if ( $@ ) {
    my $syntax_error_message = $@;
    chomp $syntax_error_message;
    $logger->fatal("OAIIngest_DC died |$syntax_error_message|");
    croak $syntax_error_message;
  }

  $logger->info('OAIIngest_DC done', 1);

  return;
}

1;

__END__

